@@ -184,7 +184,7 @@ extern "C" void EDSAbiWrapperInit()
 #ifdef EVOLUTION_COMPATIBILITY
 # ifdef HAVE_EDS
     edshandle =
-    findSymbols("libedataserver-1.2.so", 7, 13,
+    findSymbols("libedataserver-1.2.so", 7, 14,
                 FIND_SYMBOLS_NEED_ALL|FIND_SYMBOLS_LENIENT_MAX_VERSION, NULL,
                 &EDSAbiWrapperSingleton.e_source_get_type, "e_source_get_type",
                 &EDSAbiWrapperSingleton.e_source_get_uri, "e_source_get_uri",
@@ -198,7 +198,7 @@ extern "C" void EDSAbiWrapperInit()
 
 # ifdef ENABLE_EBOOK
     ebookhandle =
-    findSymbols("libebook-1.2.so", 5, 9,
+    findSymbols("libebook-1.2.so", 5, 10,
                 FIND_SYMBOLS_NEED_ALL|FIND_SYMBOLS_LENIENT_MAX_VERSION, NULL,
                 &EDSAbiWrapperSingleton.e_book_add_contact, "e_book_add_contact",
                 &EDSAbiWrapperSingleton.e_book_authenticate_user, "e_book_authenticate_user",
@@ -232,7 +232,7 @@ extern "C" void EDSAbiWrapperInit()
 
 # ifdef ENABLE_ECAL
     ecalhandle =
-    findSymbols("libecal-1.2.so", 3, 7,
+    findSymbols("libecal-1.2.so", 3, 8,
                 FIND_SYMBOLS_NEED_ALL|FIND_SYMBOLS_LENIENT_MAX_VERSION, NULL,
                 &EDSAbiWrapperSingleton.e_cal_add_timezone, "e_cal_add_timezone",
                 &EDSAbiWrapperSingleton.e_cal_component_get_icalcomponent, "e_cal_component_get_icalcomponent",
@@ -268,30 +268,53 @@ extern "C" void EDSAbiWrapperInit()
                 &EDSAbiWrapperSingleton.icalcomponent_get_location, "icalcomponent_get_location",
                 &EDSAbiWrapperSingleton.icalcomponent_get_summary, "icalcomponent_get_summary",
                 &EDSAbiWrapperSingleton.icalcomponent_get_uid, "icalcomponent_get_uid",
+                &EDSAbiWrapperSingleton.icalcomponent_get_dtstart, "icalcomponent_get_dtstart",
                 &EDSAbiWrapperSingleton.icalcomponent_isa, "icalcomponent_isa",
                 &EDSAbiWrapperSingleton.icalcomponent_new_clone, "icalcomponent_new_clone",
                 &EDSAbiWrapperSingleton.icalcomponent_new_from_string, "icalcomponent_new_from_string",
+                &EDSAbiWrapperSingleton.icalcomponent_new, "icalcomponent_new",
+                &EDSAbiWrapperSingleton.icalcomponent_merge_component, "icalcomponent_merge_component",
+                &EDSAbiWrapperSingleton.icalcomponent_remove_component, "icalcomponent_remove_component",
                 &EDSAbiWrapperSingleton.icalcomponent_remove_property, "icalcomponent_remove_property",
                 &EDSAbiWrapperSingleton.icalcomponent_set_uid, "icalcomponent_set_uid",
                 &EDSAbiWrapperSingleton.icalcomponent_set_recurrenceid, "icalcomponent_set_recurrenceid",
                 &EDSAbiWrapperSingleton.icalcomponent_vanew, "icalcomponent_vanew",
                 &EDSAbiWrapperSingleton.icalparameter_get_tzid, "icalparameter_get_tzid",
                 &EDSAbiWrapperSingleton.icalparameter_set_tzid, "icalparameter_set_tzid",
+                &EDSAbiWrapperSingleton.icalparameter_new_from_value_string, "icalparameter_new_from_value_string",
                 &EDSAbiWrapperSingleton.icalproperty_new_clone, "icalproperty_new_clone",
                 &EDSAbiWrapperSingleton.icalproperty_free, "icalproperty_free",
                 &EDSAbiWrapperSingleton.icalproperty_get_description, "icalproperty_get_description",
+                &EDSAbiWrapperSingleton.icalproperty_get_uid, "icalproperty_get_uid",
+                &EDSAbiWrapperSingleton.icalproperty_get_recurrenceid, "icalproperty_get_recurrenceid",
+                &EDSAbiWrapperSingleton.icalproperty_set_recurrenceid, "icalproperty_set_recurrenceid",
+                &EDSAbiWrapperSingleton.icalproperty_get_sequence, "icalproperty_get_sequence",
+                &EDSAbiWrapperSingleton.icalproperty_get_property_name, "icalproperty_get_property_name",
                 &EDSAbiWrapperSingleton.icalproperty_get_first_parameter, "icalproperty_get_first_parameter",
                 &EDSAbiWrapperSingleton.icalproperty_get_lastmodified, "icalproperty_get_lastmodified",
                 &EDSAbiWrapperSingleton.icalproperty_get_next_parameter, "icalproperty_get_next_parameter",
+                &EDSAbiWrapperSingleton.icalproperty_set_parameter, "icalproperty_set_parameter",
                 &EDSAbiWrapperSingleton.icalproperty_get_summary, "icalproperty_get_summary",
                 &EDSAbiWrapperSingleton.icalproperty_new_description, "icalproperty_new_description",
                 &EDSAbiWrapperSingleton.icalproperty_new_summary, "icalproperty_new_summary",
+                &EDSAbiWrapperSingleton.icalproperty_new_uid, "icalproperty_new_uid",
+                &EDSAbiWrapperSingleton.icalproperty_new_sequence, "icalproperty_new_sequence",
                 &EDSAbiWrapperSingleton.icalproperty_set_value_from_string, "icalproperty_set_value_from_string",
+                &EDSAbiWrapperSingleton.icalproperty_set_dtstamp, "icalproperty_set_dtstamp",
+                &EDSAbiWrapperSingleton.icalproperty_set_lastmodified, "icalproperty_set_lastmodified",
+                &EDSAbiWrapperSingleton.icalproperty_set_sequence, "icalproperty_set_sequence",
+                &EDSAbiWrapperSingleton.icalproperty_set_uid, "icalproperty_set_uid",
                 &EDSAbiWrapperSingleton.icalproperty_remove_parameter_by_kind, "icalproperty_remove_parameter_by_kind",
                 &EDSAbiWrapperSingleton.icaltime_is_null_time, "icaltime_is_null_time",
+                &EDSAbiWrapperSingleton.icaltime_is_utc, "icaltime_is_utc",
                 &EDSAbiWrapperSingleton.icaltime_as_ical_string, "icaltime_as_ical_string",
                 &EDSAbiWrapperSingleton.icaltime_from_string, "icaltime_from_string",
+                &EDSAbiWrapperSingleton.icaltime_from_timet, "icaltime_from_timet",
+                &EDSAbiWrapperSingleton.icaltime_null_time, "icaltime_null_time",
+                &EDSAbiWrapperSingleton.icaltime_as_timet, "icaltime_as_timet",
                 &EDSAbiWrapperSingleton.icaltime_set_timezone, "icaltime_set_timezone",
+                &EDSAbiWrapperSingleton.icaltime_convert_to_zone, "icaltime_convert_to_zone",
+                &EDSAbiWrapperSingleton.icaltime_get_timezone, "icaltime_get_timezone",
                 &EDSAbiWrapperSingleton.icaltimezone_free, "icaltimezone_free",
                 &EDSAbiWrapperSingleton.icaltimezone_get_builtin_timezone, "icaltimezone_get_builtin_timezone",
                 &EDSAbiWrapperSingleton.icaltimezone_get_builtin_timezone_from_tzid, "icaltimezone_get_builtin_timezone_from_tzid",
